@@ -1,6 +1,6 @@
 /* libhttpd.h - defines for libhttpd
 **
-** Copyright  1995,1998,1999,2000,2001 by Jef Poskanzer <jef@acme.com>.
+** Copyright  1995,1998,1999,2000,2001 by Jef Poskanzer <jef@mail.acme.com>.
 ** All rights reserved.
 **
 ** Redistribution and use in source and binary forms, with or without
@@ -84,7 +84,7 @@ typedef struct {
     int global_passwd;
     char* url_pattern;
     char* local_pattern;
-    int no_empty_referers;
+    int no_empty_referrers;
     } httpd_server;
 
 /* A connection. */
@@ -107,7 +107,7 @@ typedef struct {
     char* encodings;
     char* pathinfo;
     char* query;
-    char* referer;
+    char* referrer;
     char* useragent;
     char* accept;
     char* accepte;
@@ -169,21 +169,21 @@ typedef struct {
 ** httpd_server* which includes a socket fd that you can select() on.
 ** Return (httpd_server*) 0 on error.
 */
-extern httpd_server* httpd_initialize(
+httpd_server* httpd_initialize(
     char* hostname, httpd_sockaddr* sa4P, httpd_sockaddr* sa6P,
     unsigned short port, char* cgi_pattern, int cgi_limit, char* charset,
     char* p3p, int max_age, char* cwd, int no_log, FILE* logfp,
     int no_symlink_check, int vhost, int global_passwd, char* url_pattern,
-    char* local_pattern, int no_empty_referers );
+    char* local_pattern, int no_empty_referrers );
 
 /* Change the log file. */
-extern void httpd_set_logfp( httpd_server* hs, FILE* logfp );
+void httpd_set_logfp( httpd_server* hs, FILE* logfp );
 
 /* Call to unlisten/close socket(s) listening for new connections. */
-extern void httpd_unlisten( httpd_server* hs );
+void httpd_unlisten( httpd_server* hs );
 
 /* Call to shut down. */
-extern void httpd_terminate( httpd_server* hs );
+void httpd_terminate( httpd_server* hs );
 
 
 /* When a listen fd is ready to read, call this.  It does the accept() and
@@ -195,7 +195,7 @@ extern void httpd_terminate( httpd_server* hs );
 ** The caller is also responsible for setting initialized to zero before the
 ** first call using each different httpd_conn.
 */
-extern int httpd_get_conn( httpd_server* hs, int listen_fd, httpd_conn* hc );
+int httpd_get_conn( httpd_server* hs, int listen_fd, httpd_conn* hc );
 #define GC_FAIL 0
 #define GC_OK 1
 #define GC_NO_MORE 2
@@ -207,7 +207,7 @@ extern int httpd_get_conn( httpd_server* hs, int listen_fd, httpd_conn* hc );
 ** indication of whether there is no complete request yet, there is a
 ** complete request, or there won't be a valid request due to a syntax error.
 */
-extern int httpd_got_request( httpd_conn* hc );
+int httpd_got_request( httpd_conn* hc );
 #define GR_NO_REQUEST 0
 #define GR_GOT_REQUEST 1
 #define GR_BAD_REQUEST 2
@@ -217,7 +217,7 @@ extern int httpd_got_request( httpd_conn* hc );
 **
 ** Returns -1 on error.
 */
-extern int httpd_parse_request( httpd_conn* hc );
+int httpd_parse_request( httpd_conn* hc );
 
 /* Starts sending data back to the client.  In some cases (directories,
 ** CGI programs), finishes sending by itself - in those cases, hc->file_fd
@@ -227,27 +227,28 @@ extern int httpd_parse_request( httpd_conn* hc );
 **
 ** Returns -1 on error.
 */
-extern int httpd_start_request( httpd_conn* hc, struct timeval* nowP );
+int httpd_start_request( httpd_conn* hc, struct timeval* nowP );
 
 /* Actually sends any buffered response text. */
-extern void httpd_write_response( httpd_conn* hc );
+void httpd_write_response( httpd_conn* hc );
 
 /* Call this to close down a connection and free the data.  A fine point,
 ** if you fork() with a connection open you should still call this in the
 ** parent process - the connection will stay open in the child.
 ** If you don't have a current timeval handy just pass in 0.
 */
-extern void httpd_close_conn( httpd_conn* hc, struct timeval* nowP );
+void httpd_close_conn( httpd_conn* hc, struct timeval* nowP );
 
 /* Call this to de-initialize a connection struct and *really* free the
 ** mallocced strings.
 */
-extern void httpd_destroy_conn( httpd_conn* hc );
+void httpd_destroy_conn( httpd_conn* hc );
 
 
 /* Send an error message back to the client. */
-extern void httpd_send_err(
-    httpd_conn* hc, int status, char* title, char* extraheads, char* form, char* arg );
+void httpd_send_err(
+    httpd_conn* hc, int status, char* title, char* extraheads, char* form,
+    char* arg );
 
 /* Some error messages. */
 extern char* httpd_err400title;
@@ -258,27 +259,27 @@ extern char* httpd_err503title;
 extern char* httpd_err503form;
 
 /* Generate a string representation of a method number. */
-extern char* httpd_method_str( int method );
+char* httpd_method_str( int method );
 
 /* Reallocate a string. */
-extern void httpd_realloc_str( char** strP, size_t* maxsizeP, size_t size );
+void httpd_realloc_str( char** strP, size_t* maxsizeP, size_t size );
 
 /* Format a network socket to a string representation. */
-extern char* httpd_ntoa( httpd_sockaddr* saP );
+char* httpd_ntoa( httpd_sockaddr* saP );
 
 /* Set NDELAY mode on a socket. */
-extern void httpd_set_ndelay( int fd );
+void httpd_set_ndelay( int fd );
 
 /* Clear NDELAY mode on a socket. */
-extern void httpd_clear_ndelay( int fd );
+void httpd_clear_ndelay( int fd );
 
 /* Read the requested buffer completely, accounting for interruptions. */
-extern int httpd_read_fully( int fd, void* buf, size_t nbytes );
+int httpd_read_fully( int fd, void* buf, size_t nbytes );
 
 /* Write the requested buffer completely, accounting for interruptions. */
-extern int httpd_write_fully( int fd, const void* buf, size_t nbytes );
+int httpd_write_fully( int fd, const char* buf, size_t nbytes );
 
 /* Generate debugging statistics syslog message. */
-extern void httpd_logstats( long secs );
+void httpd_logstats( long secs );
 
 #endif /* _LIBHTTPD_H_ */
