@@ -1,6 +1,6 @@
 /* thttpd.c - tiny/turbo/throttling HTTP server
 **
-** Copyright  1995,1998,1999,2000,2001 by Jef Poskanzer <jef@acme.com>.
+** Copyright  1995,1998,1999,2000,2001 by Jef Poskanzer <jef@mail.acme.com>.
 ** All rights reserved.
 **
 ** Redistribution and use in source and binary forms, with or without
@@ -78,7 +78,7 @@ static int do_chroot, no_log, no_symlink_check, do_vhost, do_global_passwd;
 static char* cgi_pattern;
 static int cgi_limit;
 static char* url_pattern;
-static int no_empty_referers;
+static int no_empty_referrers;
 static char* local_pattern;
 static char* logfile;
 static char* throttlefile;
@@ -137,7 +137,7 @@ long stats_connections;
 off_t stats_bytes;
 int stats_simultaneous;
 
-static int got_hup, got_usr1, watchdog_flag;
+static volatile int got_hup, got_usr1, watchdog_flag;
 
 
 /* Forwards. */
@@ -148,7 +148,7 @@ static void value_required( char* name, char* value );
 static void no_value_required( char* name, char* value );
 static char* e_strdup( char* oldstr );
 static void lookup_hostname( httpd_sockaddr* sa4P, size_t sa4_len, int* gotv4P, httpd_sockaddr* sa6P, size_t sa6_len, int* gotv6P );
-static void read_throttlefile( char* throttlefile );
+static void read_throttlefile( char* tf );
 static void shut_down( void );
 static int handle_newconnect( struct timeval* tvP, int listen_fd );
 static void handle_read( connecttab* c, struct timeval* tvP );
@@ -544,6 +544,17 @@ main( int argc, char** argv )
 	(void) fclose( pidfp );
 	}
 
+    /* Initialize the fdwatch package.  Have to do this before chroot,
+    ** if /dev/poll is used.
+    */
+    max_connects = fdwatch_get_nfiles();
+    if ( max_connects < 0 )
+	{
+	syslog( LOG_CRIT, "fdwatch initialization failure" );
+	exit( 1 );
+	}
+    max_connects -= SPARE_FDS;
+
     /* Chroot if requested. */
     if ( do_chroot )
 	{
@@ -631,7 +642,7 @@ main( int argc, char** argv )
 	gotv4 ? &sa4 : (httpd_sockaddr*) 0, gotv6 ? &sa6 : (httpd_sockaddr*) 0,
 	port, cgi_pattern, cgi_limit, charset, p3p, max_age, cwd, no_log, logfp,
 	no_symlink_check, do_vhost, do_global_passwd, url_pattern,
-	local_pattern, no_empty_referers );
+	local_pattern, no_empty_referrers );
     if ( hs == (httpd_server*) 0 )
 	exit( 1 );
 
@@ -705,13 +716,6 @@ main( int argc, char** argv )
 	}
 
     /* Initialize our connections table. */
-    max_connects = fdwatch_get_nfiles();
-    if ( max_connects < 0 )
-	{
-	syslog( LOG_CRIT, "fdwatch initialization failure" );
-	exit( 1 );
-	}
-    max_connects -= SPARE_FDS;
     connects = NEW( connecttab, max_connects );
     if ( connects == (connecttab*) 0 )
 	{
@@ -866,7 +870,7 @@ parse_args( int argc, char** argv )
     cgi_limit = 0;
 #endif /* CGI_LIMIT */
     url_pattern = (char*) 0;
-    no_empty_referers = 0;
+    no_empty_referrers = 0;
     local_pattern = (char*) 0;
     throttlefile = (char*) 0;
     hostname = (char*) 0;
@@ -1065,26 +1069,16 @@ read_config( char* filename )
 		value_required( name, value );
 		data_dir = e_strdup( value );
 		}
-	    else if ( strcasecmp( name, "symlink" ) == 0 )
-		{
-		no_value_required( name, value );
-		no_symlink_check = 0;
-		}
-	    else if ( strcasecmp( name, "nosymlink" ) == 0 )
+	    else if ( strcasecmp( name, "nosymlinkcheck" ) == 0 )
 		{
 		no_value_required( name, value );
 		no_symlink_check = 1;
 		}
-	    else if ( strcasecmp( name, "symlinks" ) == 0 )
+	    else if ( strcasecmp( name, "symlinkcheck" ) == 0 )
 		{
 		no_value_required( name, value );
 		no_symlink_check = 0;
 		}
-	    else if ( strcasecmp( name, "nosymlinks" ) == 0 )
-		{
-		no_value_required( name, value );
-		no_symlink_check = 1;
-		}
 	    else if ( strcasecmp( name, "user" ) == 0 )
 		{
 		value_required( name, value );
@@ -1105,10 +1099,11 @@ read_config( char* filename )
 		value_required( name, value );
 		url_pattern = e_strdup( value );
 		}
-	    else if ( strcasecmp( name, "noemptyreferers" ) == 0 )
+	    else if ( strcasecmp( name, "noemptyreferers" ) == 0 ||
+	              strcasecmp( name, "noemptyreferrers" ) == 0 )
 		{
 		no_value_required( name, value );
-		no_empty_referers = 1;
+		no_empty_referrers = 1;
 		}
 	    else if ( strcasecmp( name, "localpat" ) == 0 )
 		{
@@ -1363,7 +1358,7 @@ lookup_hostname( httpd_sockaddr* sa4P, size_t sa4_len, int* gotv4P, httpd_sockad
 
 
 static void
-read_throttlefile( char* throttlefile )
+read_throttlefile( char* tf )
     {
     FILE* fp;
     char buf[5000];
@@ -1373,11 +1368,11 @@ read_throttlefile( char* throttlefile )
     long max_limit, min_limit;
     struct timeval tv;
 
-    fp = fopen( throttlefile, "r" );
+    fp = fopen( tf, "r" );
     if ( fp == (FILE*) 0 )
 	{
-	syslog( LOG_CRIT, "%.80s - %m", throttlefile );
-	perror( throttlefile );
+	syslog( LOG_CRIT, "%.80s - %m", tf );
+	perror( tf );
 	exit( 1 );
 	}
 
@@ -1409,10 +1404,10 @@ read_throttlefile( char* throttlefile )
 	else
 	    {
 	    syslog( LOG_CRIT,
-		"unparsable line in %.80s - %.80s", throttlefile, buf );
+		"unparsable line in %.80s - %.80s", tf, buf );
 	    (void) fprintf( stderr,
 		"%s: unparsable line in %.80s - %.80s\n",
-		argv0, throttlefile, buf );
+		argv0, tf, buf );
 	    continue;
 	    }
 
@@ -2178,7 +2173,7 @@ thttpd_logstats( long secs )
 	syslog( LOG_INFO,
 	    "  thttpd - %ld connections (%g/sec), %d max simultaneous, %lld bytes (%g/sec), %d httpd_conns allocated",
 	    stats_connections, (float) stats_connections / secs,
-	    stats_simultaneous, (int64_t) stats_bytes,
+	    stats_simultaneous, (long long) stats_bytes,
 	    (float) stats_bytes / secs, httpd_conn_count );
     stats_connections = 0;
     stats_bytes = 0;
